@@ -36,3 +36,7 @@ class Profiles(CRUD, JamfRecord):
 
 class DeviceGroups(CRUD, JamfRecord):
     path = 'JSSResource/mobiledevicegroups'
+
+
+class Users(CRUD, JamfRecord):
+    path = 'JSSResource/users'
